#
# spec file for package pavucontrol
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pavucontrol
Version:        5.0
Release:        1.10
Summary:        PulseAudio Volume Control
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Mixers
URL:            https://freedesktop.org/software/pulseaudio/pavucontrol/
Source:         https://freedesktop.org/software/pulseaudio/pavucontrol/%{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.22
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.16
BuildRequires:  pkgconfig(libpulse) >= 0.9.16
BuildRequires:  pkgconfig(libpulse-mainloop-glib) >= 0.9.16
BuildRequires:  pkgconfig(sigc++-2.0)
%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif

%description
PulseAudio Volume Control (pavucontrol) is a simple GTK based volume
control tool ("mixer") for the PulseAudio sound server. In contrast to
classic mixer tools this one allows you to control both the volume of
hardware devices and of each playback stream separately.

%lang_package

%prep
%setup -q

%build
%configure --disable-lynx
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name} %{?no_lang_C}

# This is documentation we prefer to have in the package doc directory
rm -r %{buildroot}%{_datadir}/doc/%{name}

%files
%license LICENSE
%doc doc/README doc/README.html doc/style.css
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop

%files lang -f %{name}.lang

%changelog
* Wed Aug 18 2021 Robert Munteanu <rombert@apache.org>
- Update to version 5.0:
  * Support for switching Bluetooth codecs (new in PulseAudio 15.0).
  * Support for locking card profiles (new in PulseAudio 15.0).
    Locking a profile prevents PulseAudio from automatically switching
    away from that profile on plug/unplug events.
  * New translations: Asturian, Basque, Belarusian, Galician, Hebrew,
    Kazakh, Norwegian Bokmål, Sinhala, Slovenian
  * Updated translations: Catalan, Chinese (Simplified), Chinese
    (Traditional), Croatian, Danish, Dutch, Finnish, French, German,
    Hungarian, Italian, Japanese, Korean, Lithuanian, Norwegian
    Nynorsk, Polish, Portugese, Portugese (Brazil), Slovak, Spanish,
    Swedish, Turkish, Ukrainian.
  * Some bug fixes.
  * New dependency: json-glib.
  * Minimum gtkmm version bumped to 3.22.
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Fri Sep  6 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Add runtime requirement on pulseaudio (boo#1149634).
- Refresh spec file.
* Sun Jun 30 2019 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 4.0:
  * There can now be only one pavucontrol window open at a time.
    Trying to start pavucontrol for a second time brings the first
    window to foreground.
  * Added a "Show volume meters" checkbox to the Configuration tab.
    Disabling the volume meters reduces CPU use.
  * Improve the use of space (remove useless margins and paddings).
  * Use a more appropriate icon for the channel lock button.
  * Better channel label layout, prevents volume sliders from getting
    unaligned.
  * Maximum latency offset increased from 2 to 5 seconds to
    accommodate AirPlay devices that often have higher latency than
    2 seconds (this is not that useful on newer PulseAudio versions,
    though, because the latency is reported much more accurately
    than before).
  * New --version command line option.
  * Dropped support for Gtk+ 2.
  * Bumped the minimum supported libpulse version to 5.0.
  * Improved compatibility with newer Glade versions.
  * New translations: Chinese (Taiwan), Croatian, Korean, Norwegian
    Nynorsk, Lithuanian, Valencian.
  * Updated translations: Finnish, French, German, Italian,
    Japanese, Polish, Swedish.
- cleanup with spec-cleaner
- drop pavucontrol-use-C++11-for-building.patch (upstreamed)
* Mon Jan 16 2017 zaitor@opensuse.org
- Add pavucontrol-use-C++11-for-building.patch: Use C++11 for
  building, patch from upstream git.
- Following the above add libtool BuildRequires and pass autoreconf
  as the patch touches the buildsystem.
- Drop obsolete clean section and conditionals for obsolete
  versions of openSUSE.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.0:
  + sinkwidget: add support for AAC pass-through.
  + added back support for gtkmm-2.4 builds.
  + pavucontrol: ellipsize labels to fix window resizing.
  + Don't crash if pa_stream_peek returns NULL.
  + Handle IO errors in icon setting code.
  + Reference the widget before returning it from ::create
    methods.
  + Do not instantiate cardwidget, devicewidget and rolewidget with
    a type of EventBox.
  + devicewidget, streamwidget: Show only one volume slider when
    channels are locked.
  + mainwindow: Catch Gdk::PixbufError.
  + Add a --maximize command line option.
  + Add horizontal scrollbars automatically.
  + mainwindow: Remember device visibility selections.
  + Build system fixes.
- Drop pavucontrol-2.0-reference-widget.patch: fixed upstream.
* Sun Oct 12 2014 antoine.belvire@laposte.net
- Add pavucontrol-2.0-reference-widget.patch: Reference the widget
  before returning it from ::create methods (boo#900797).
* Wed Apr  3 2013 dimstar@opensuse.org
- Update to version 2.0:
  + Fix theme under gtk3.
  + Support recent PulseAudio port feature additions
  + devicewidget: Move latency offset into an expander.
  + sinkwidget: Move format selection options to 'Advanced'
    expander.
  + Add a few known peak-detect stream clients to a source-output
    blacklist.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 1.0:
  + Add GTK+3 support.
  + Add source output volume support.
  + Add digitial receiver UI.
  + Handle simple key events.
  + Bug fixes.
- Remove libglademm-devel BuildRequires: not needed anymore.
- Add pkgconfig(sigc++-2.0) BuildRequires: it was implicit before.
- Use favor_gtk2 to switch between gtk2 and gtk3 builds.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: gtkmm2-devel, libcanberra-devel, libpulse-devel.
  + New ones: gtkmm-2.4/gtkmm-3.0,
    libcanberra-gtk/libcanberra-gtk3, libpulse,
    libpulse-mainloop-glib.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Split lang subpackage.
* Sun Aug  8 2010 vuntz@opensuse.org
- Add explicit gtkmm2-devel BuildRequires.
- Remove libcanberra-gtk and libsndfile-devel BuildRequires.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 0.9.10:
  + volume: Set the scale properly for delta changes via
    mouse/keyboard.
  + events: Hide output streams with a stream restore designator
    for the event widget.
  + Build fixes.
  + Updated translations.
* Sat Sep 19 2009 sreeves@novell.com
- Update to version 0.9.9
  + make sure that two card profiles with the same priority
    don't collide with each other
  + Add support for changing ports
  + Change 'Default' to 'Use as fallback'
  + Create the event role widget early so that it's always top of
    the list.
  + More changes in the UI to try and make things neater.
  + Hide the terminate button.
  + Do not disable the default button when it's set.
  + Don't use a hyperlink to display the device, just use a
    regular button.
  + Add support for changing ports.
* Thu May  7 2009 vuntz@novell.com
- Review changes.
- Drop pavucontrol.png: there's no reason to install this icon. Was
  probably a left-over.
- Remove autoreconf call, which isn't needed.
- Pass --disable-lynx to configure, and remove lynx BuildRequires.
- Use parallel make.
- Do not add categories to the desktop file, since they're already
  there.
- Use standard commands for clean section.
* Thu Apr 30 2009 opensuse@sukimashita.com
- Update to version 0.9.8:
  + Support for changing card profiles.
  + Add Configuration tab.
  + Use the server provided icons.
  + Visualize base volume.
  + Configure steps for scales.
  + Don't show wait cursor forever if stream_restore extension is
    not available.
  + Reenable monitor streams.
  + Don't show failure msgbox twice.
  + Code reorganization.
  + Various cleanups.
  + Updated translations.
- Remove /usr/share/doc/pavucontrol since it's documentation that
  we already have elsewhere.
* Tue Sep 30 2008 aj@suse.de
- Fix filelist.
* Tue Sep 16 2008 rodrigo@suse.de
- Update to version 0.9.7 (fate#303943):
  + Show stream icons, and don't show our own monitor streams
  + Initilize client proplist properly
  + Make icons work
  + Fix Glade widget name case
  + Add a special track for controlling event sound volume
  + Update license headers for GPL 2.0+
  + Use system installed glade file
  + Add i18n
  + Beep when changing volume
  + Initialize maximum buffer length to automatic value
  + Updated translations
- Removed unneeded patch
- Added build dependency on libcanberra-devel|-gtk and intltool
- Added translations to package
* Wed Jul 30 2008 rodrigo@suse.de
- Update to version 0.9.6:
  * Draw radio buttons instead of check boxes when moving streams
  * Fix crasher when connecting to a PA server that has no default
    sink/source configured
* Fri Jan 11 2008 rodrigo@suse.de
- Depend on libpulse-devel, not pulseaudio-devel
* Tue Dec 11 2007 rodrigo@suse.de
- Updated to latest version (0.9.5):
  * Build fixes
  * Make stream title selectable (#140 in PulseAudio trac)
  * Add popup menu to sink/source to choose default device
  * Use pretty channel names
  * Add a combobox to the streams page, to filter app streams.
- Removed --disable-lynx from configure
* Wed Jun 13 2007 tiwai@suse.de
- initial version: 0.9.4
